@@ -104,7 +104,7 @@ def create_depgraph_params(myopts, myaction):
     if ignore_built_slot_operator_deps is not None:
         myparams["ignore_built_slot_operator_deps"] = ignore_built_slot_operator_deps
 
-    myparams["ignore_soname_deps"] = myopts.get("--ignore-soname-deps", "n")
+    myparams["ignore_soname_deps"] = myopts.get("--ignore-soname-deps", "y")
 
     dynamic_deps = myopts.get("--dynamic-deps", "y") != "n" and "--nodeps" not in myopts
     if dynamic_deps:
