@@ -22,7 +22,7 @@ class slot_conflict_handler:
     go away. This class focuses on cases where this can be achieved
     with a change in USE settings.
 
-    1) Find out if what causes a given slot conflict. There are
+    1) Find out what causes a given slot conflict. There are
     three possibilities:
 
             a) One parent needs foo-1:0 and another one needs foo-2:0,
@@ -36,7 +36,7 @@ class slot_conflict_handler:
             enabled, this case is treated in the same way as c).
 
             c) Neither a 'version based conflict' nor an 'unspecific
-            conflict'. Ignoring use deps would result result in an
+            conflict'. Ignoring use deps would result in an
             'unspecific conflict'. This is called a 'specific conflict'.
             This is the only conflict we try to find suggestions for.
 
@@ -63,7 +63,7 @@ class slot_conflict_handler:
             * The parent package is 'installed'.
             * The conflict package is 'installed'.
 
-    USE of 'installed' packages can't be changed. This always requires an
+    USE of 'installed' packages can't be changed. This always requires a
     non-installed package.
 
     During this procedure, contradictions may occur. In this case the
@@ -126,10 +126,10 @@ class slot_conflict_handler:
 
         self._prepare_conflict_msg_and_check_for_specificity()
 
-        # a list of dicts that hold the needed USE values to solve all conflicts
+        # a list of dicts that holds the needed USE values to solve all conflicts
         self.solutions = []
 
-        # a list of dicts that hold the needed USE changes to solve all conflicts
+        # a list of dicts that holds the needed USE changes to solve all conflicts
         self.changes = []
 
         # configuration = a list of packages with exactly one package from every
@@ -146,7 +146,7 @@ class slot_conflict_handler:
             if self.debug:
                 writemsg("\nNew configuration:\n", noiselevel=-1)
                 for pkg in config:
-                    writemsg("   %s\n" % (pkg,), noiselevel=-1)
+                    writemsg("   {}\n".format(pkg), noiselevel=-1)
                 writemsg("\n", noiselevel=-1)
 
             new_solutions = self._check_configuration(
@@ -218,7 +218,7 @@ class slot_conflict_handler:
                 to_be_removed.append(change)
 
         if not ignore:
-            # Discard all existing change that are a superset of the new change.
+            # Discard all existing changes that are a superset of the new change.
             for obsolete_change in to_be_removed:
                 changes.remove(obsolete_change)
             changes.append(new_change)
@@ -228,14 +228,14 @@ class slot_conflict_handler:
         new_change = {}
         for pkg in solution:
             for flag, state in solution[pkg].items():
-                real_flag = pkg.iuse.get_real_flag(flag)
-                if real_flag is None:
+                flag = pkg.iuse.get_flag(flag)
+                if flag is None:
                     # Triggered by use-dep defaults.
                     continue
                 if state == "enabled" and flag not in _pkg_use_enabled(pkg):
-                    new_change.setdefault(pkg, {})[real_flag] = True
+                    new_change.setdefault(pkg, {})[flag] = True
                 elif state == "disabled" and flag in _pkg_use_enabled(pkg):
-                    new_change.setdefault(pkg, {})[real_flag] = False
+                    new_change.setdefault(pkg, {})[flag] = False
         return new_change
 
     def _prepare_conflict_msg_and_check_for_specificity(self):
@@ -258,9 +258,9 @@ class slot_conflict_handler:
         )
 
         for root, slot_atom, pkgs in self.all_conflicts:
-            msg.append("%s" % (slot_atom,))
+            msg.append("{}".format(slot_atom))
             if root != self.depgraph._frozen_config._running_root.root:
-                msg.append(" for %s" % (root,))
+                msg.append(" for {}".format(root))
             msg.append("\n\n")
 
             for pkg in pkgs:
@@ -523,7 +523,7 @@ class slot_conflict_handler:
 
                     def highlight_violations(atom, version, use, slot_violated):
                         """Colorize parts of an atom"""
-                        atom_str = "%s" % (atom,)
+                        atom_str = "{}".format(atom)
                         colored_idx = set()
                         if version:
                             op = atom.operator
@@ -614,7 +614,7 @@ class slot_conflict_handler:
 
                             atom_str = (
                                 atom_str[:use_part_start]
-                                + "[%s]" % (",".join(new_tokens),)
+                                + "[{}]".format(",".join(new_tokens))
                                 + atom_str[use_part_end + 1 :]
                             )
 
@@ -639,15 +639,17 @@ class slot_conflict_handler:
                             use_display = ""
                         if atom.soname:
                             msg.append(
-                                "%s required by %s %s\n" % (atom, parent, use_display)
+                                "{} required by {} {}\n".format(
+                                    atom, parent, use_display
+                                )
                             )
                         elif isinstance(parent, PackageArg):
                             # For PackageArg it's
                             # redundant to display the atom attribute.
-                            msg.append("%s\n" % (parent,))
+                            msg.append("{}\n".format(parent))
                         elif isinstance(parent, AtomArg):
                             msg.append(2 * indent)
-                            msg.append("%s (Argument)\n" % (atom,))
+                            msg.append("{} (Argument)\n".format(atom))
                         else:
                             # Display the specific atom from SetArg or
                             # Package types.
@@ -675,7 +677,7 @@ class slot_conflict_handler:
                             if version_violated or slot_violated:
                                 self.is_a_version_conflict = True
 
-                            cur_line = "%s required by %s %s\n" % (
+                            cur_line = "{} required by {} {}\n".format(
                                 atom_str,
                                 parent,
                                 use_display,
@@ -736,7 +738,7 @@ class slot_conflict_handler:
             )
             msg.append("!!! package(s) cannot be rebuilt for the reason(s) shown:\n\n")
             for ppkg, reason in need_rebuild.items():
-                msg.append("%s%s: %s\n" % (indent, ppkg, reason))
+                msg.append("{}{}: {}\n".format(indent, ppkg, reason))
             msg.append("\n")
 
         msg.append("\n")
@@ -803,12 +805,12 @@ class slot_conflict_handler:
         self, config, all_conflict_atoms_by_slotatom, conflict_nodes
     ):
         """
-        Given a configuartion, required use changes are computed and checked to
+        Given a configuration, required use changes are computed and checked to
         make sure that no new conflict is introduced. Returns a solution or None.
         """
         _pkg_use_enabled = self.depgraph._pkg_use_enabled
         # An installed package can only be part of a valid configuration if it has no
-        # pending use changed. Otherwise the ebuild will be pulled in again.
+        # pending use changes. Otherwise the ebuild will be pulled in again.
         for pkg in config:
             if not pkg.installed:
                 continue
@@ -908,7 +910,7 @@ class slot_conflict_handler:
                     violated_atom.use.enabled or violated_atom.use.disabled
                 ):
                     # We can't change USE of an installed package (only of an ebuild, but that is already
-                    # part of the conflict, isn't it?
+                    # part of the conflict, isn't it?)
                     if self.debug:
                         writemsg(
                             (
@@ -922,7 +924,7 @@ class slot_conflict_handler:
 
                 # Compute the required USE changes. A flag can be forced to "enabled" or "disabled",
                 # it can be in the conditional state "cond" that allows both values or in the
-                # "contradiction" state, which means that some atoms insist on differnt values
+                # "contradiction" state, which means that some atoms insist on different values
                 # for this flag and those kill this configuration.
                 for flag in violated_atom.use.required:
                     state = involved_flags.get(flag, "")
@@ -975,7 +977,7 @@ class slot_conflict_handler:
         if self.debug:
             writemsg("All involved flags:\n", noiselevel=-1)
             for idx, involved_flags in enumerate(all_involved_flags):
-                writemsg("   %s\n" % (config[idx],), noiselevel=-1)
+                writemsg("   {}\n".format(config[idx]), noiselevel=-1)
                 for flag, state in involved_flags.items():
                     writemsg("     " + flag + ": " + state + "\n", noiselevel=-1)
 
@@ -1013,7 +1015,7 @@ class slot_conflict_handler:
 
     def _force_flag_for_package(self, required_changes, pkg, flag, state):
         """
-        Adds an USE change to required_changes. Sets the target state to
+        Adds a USE change to required_changes. Sets the target state to
         "contradiction" if a flag is forced to conflicting values.
         """
         _pkg_use_enabled = self.depgraph._pkg_use_enabled
@@ -1043,7 +1045,7 @@ class slot_conflict_handler:
         self, config, all_involved_flags, all_conflict_atoms_by_slotatom
     ):
         """
-        Given a configuartion and all involved flags, all possible settings for the involved
+        Given a configuration and all involved flags, all possible settings for the involved
         flags are checked if they solve the slot conflict.
         """
         _pkg_use_enabled = self.depgraph._pkg_use_enabled
@@ -1066,7 +1068,7 @@ class slot_conflict_handler:
                         inner_first = False
                     else:
                         msg += ", "
-                    msg += flag + ": %s" % (state,)
+                    msg += flag + ": {}".format(state)
                 msg += "}"
             msg += "]\n"
             writemsg(msg, noiselevel=-1)
@@ -1281,7 +1283,7 @@ class _solution_candidate_generator:
             return self.value == other.value
 
         def __str__(self):
-            return "%s" % (self.value,)
+            return "{}".format(self.value)
 
     def __init__(self, all_involved_flags):
         # A copy of all_involved_flags with all "cond" values
