@@ -9,6 +9,8 @@ from portage.package.ebuild.fetch import ContentHashLayout
 from portage.util._async.FileCopier import FileCopier
 from _emerge.CompositeTask import CompositeTask
 
+logger = logging.getLogger(__name__)
+
 
 class DeletionTask(CompositeTask):
 
@@ -18,19 +20,17 @@ class DeletionTask(CompositeTask):
         if self.config.options.recycle_dir is not None:
             recycle_path = os.path.join(self.config.options.recycle_dir, self.distfile)
             if self.config.options.dry_run:
-                logging.info(
+                logger.info(
                     ("dry-run: move '%s' from " "distfiles to recycle") % self.distfile
                 )
             else:
-                logging.debug(
-                    ("move '%s' from " "distfiles to recycle") % self.distfile
-                )
+                logger.debug(("move '%s' from " "distfiles to recycle") % self.distfile)
                 try:
                     # note: distfile_path can be a symlink here
                     os.rename(os.path.realpath(self.distfile_path), recycle_path)
                 except OSError as e:
                     if e.errno != errno.EXDEV:
-                        logging.error(
+                        logger.error(
                             ("rename %s from distfiles to " "recycle failed: %s")
                             % (self.distfile, e)
                         )
@@ -52,15 +52,15 @@ class DeletionTask(CompositeTask):
         success = True
 
         if self.config.options.dry_run:
-            logging.info(("dry-run: delete '%s' from " "distfiles") % self.distfile)
+            logger.info(("dry-run: delete '%s' from " "distfiles") % self.distfile)
         else:
-            logging.debug(("delete '%s' from " "distfiles") % self.distfile)
+            logger.debug(("delete '%s' from " "distfiles") % self.distfile)
             try:
                 os.unlink(self.distfile_path)
             except OSError as e:
                 if e.errno not in (errno.ENOENT, errno.ESTALE):
-                    logging.error(
-                        "%s unlink failed in distfiles: %s" % (self.distfile, e)
+                    logger.error(
+                        "{} unlink failed in distfiles: {}".format(self.distfile, e)
                     )
                     success = False
 
@@ -85,13 +85,13 @@ class DeletionTask(CompositeTask):
                 os.unlink(copier.src_path)
             except OSError as e:
                 if e.errno not in (errno.ENOENT, errno.ESTALE):
-                    logging.error(
-                        "%s unlink failed in distfiles: %s" % (self.distfile, e)
+                    logger.error(
+                        "{} unlink failed in distfiles: {}".format(self.distfile, e)
                     )
                     success = False
 
         else:
-            logging.error(
+            logger.error(
                 ("%s copy from distfiles " "to recycle failed: %s")
                 % (self.distfile, copier.future.exception())
             )
@@ -109,7 +109,7 @@ class DeletionTask(CompositeTask):
         success = True
         for layout in self.config.layouts:
             if isinstance(layout, ContentHashLayout) and not self.distfile.digests:
-                logging.debug(("_delete_links: '%s' has " "no digests") % self.distfile)
+                logger.debug(("_delete_links: '%s' has " "no digests") % self.distfile)
                 continue
             distfile_path = os.path.join(
                 self.config.options.distfiles, layout.get_path(self.distfile)
@@ -118,8 +118,8 @@ class DeletionTask(CompositeTask):
                 os.unlink(distfile_path)
             except OSError as e:
                 if e.errno not in (errno.ENOENT, errno.ESTALE):
-                    logging.error(
-                        "%s unlink failed in distfiles: %s" % (self.distfile, e)
+                    logger.error(
+                        "{} unlink failed in distfiles: {}".format(self.distfile, e)
                     )
                     success = False
 
@@ -136,7 +136,7 @@ class DeletionTask(CompositeTask):
             cpv = self.config.distfiles_db.get(self.distfile, cpv)
 
         self.config.delete_count += 1
-        self.config.log_success("%s\t%s\tremoved" % (cpv, self.distfile))
+        self.config.log_success("{}\t{}\tremoved".format(cpv, self.distfile))
 
         if self.config.distfiles_db is not None:
             try:
@@ -144,7 +144,7 @@ class DeletionTask(CompositeTask):
             except KeyError:
                 pass
             else:
-                logging.debug(("drop '%s' from " "distfiles db") % self.distfile)
+                logger.debug(("drop '%s' from " "distfiles db") % self.distfile)
 
         if self.config.content_db is not None:
             self.config.content_db.remove(self.distfile)
@@ -155,4 +155,4 @@ class DeletionTask(CompositeTask):
             except KeyError:
                 pass
             else:
-                logging.debug(("drop '%s' from " "deletion db") % self.distfile)
+                logger.debug(("drop '%s' from " "deletion db") % self.distfile)
