@@ -161,7 +161,7 @@ class _better_cache:
                 continue
             for p in pkg_list:
                 try:
-                    atom = Atom("%s/%s" % (cat, p))
+                    atom = Atom("{}/{}".format(cat, p))
                 except InvalidAtom:
                     continue
                 if atom != atom.cp:
@@ -332,26 +332,24 @@ class portdbapi(dbapi):
                 if cache is not None:
                     self._pregen_auxdb[x] = cache
         # Selectively cache metadata in order to optimize dep matching.
-        self._aux_cache_keys = set(
-            [
-                "BDEPEND",
-                "DEPEND",
-                "EAPI",
-                "IDEPEND",
-                "INHERITED",
-                "IUSE",
-                "KEYWORDS",
-                "LICENSE",
-                "PDEPEND",
-                "PROPERTIES",
-                "RDEPEND",
-                "repository",
-                "RESTRICT",
-                "SLOT",
-                "DEFINED_PHASES",
-                "REQUIRED_USE",
-            ]
-        )
+        self._aux_cache_keys = {
+            "BDEPEND",
+            "DEPEND",
+            "EAPI",
+            "IDEPEND",
+            "INHERITED",
+            "IUSE",
+            "KEYWORDS",
+            "LICENSE",
+            "PDEPEND",
+            "PROPERTIES",
+            "RDEPEND",
+            "repository",
+            "RESTRICT",
+            "SLOT",
+            "DEFINED_PHASES",
+            "REQUIRED_USE",
+        }
 
         self._aux_cache = {}
         self._better_cache = None
@@ -367,14 +365,14 @@ class portdbapi(dbapi):
                 repo priority
         @type porttrees: list
         """
+        self._porttrees = tuple(porttrees)
         self._porttrees_repos = portage.OrderedDict(
             (repo.name, repo)
             for repo in (
                 self.repositories.get_repo_for_location(location)
-                for location in porttrees
+                for location in self._porttrees
             )
         )
-        self._porttrees = tuple(porttrees)
 
     def _get_porttrees(self):
         return self._porttrees
@@ -888,7 +886,9 @@ class portdbapi(dbapi):
                 # since callers already handle it.
                 result.set_exception(
                     portage.exception.InvalidDependString(
-                        "getFetchMap(): '%s' has unsupported EAPI: '%s'" % (mypkg, eapi)
+                        "getFetchMap(): '{}' has unsupported EAPI: '{}'".format(
+                            mypkg, eapi
+                        )
                     )
                 )
                 return
@@ -1065,7 +1065,7 @@ class portdbapi(dbapi):
                     oroot + "/" + x, EmptyOnError=1, ignorecvs=1, dirsonly=1
                 ):
                     try:
-                        atom = Atom("%s/%s" % (x, y))
+                        atom = Atom("{}/{}".format(x, y))
                     except InvalidAtom:
                         continue
                     if atom != atom.cp:
@@ -1436,10 +1436,10 @@ class portdbapi(dbapi):
                     continue
                 except PortageException as e:
                     writemsg(
-                        "!!! Error: aux_get('%s', %s)\n" % (mycpv, aux_keys),
+                        "!!! Error: aux_get('{}', {})\n".format(mycpv, aux_keys),
                         noiselevel=-1,
                     )
-                    writemsg("!!! %s\n" % (e,), noiselevel=-1)
+                    writemsg("!!! {}\n".format(e), noiselevel=-1)
                     del e
                     continue
 
@@ -1705,10 +1705,7 @@ def _async_manifest_fetchlist(
             return
         if e is None:
             result.set_result(
-                dict(
-                    (k, list(v.result()))
-                    for k, v in zip(cpv_list, gather_result.result())
-                )
+                {k: list(v.result()) for k, v in zip(cpv_list, gather_result.result())}
             )
         else:
             result.set_exception(e)
