@@ -78,15 +78,17 @@ def _expand_new_virtuals(
             newsplit.append(x)
             continue
         elif isinstance(x, list):
-            assert x, "Normalization error, empty conjunction found in %s" % (mysplit,)
+            assert x, "Normalization error, empty conjunction found in {}".format(
+                mysplit
+            )
             if is_disjunction:
                 assert (
                     x[0] != "||"
-                ), "Normalization error, nested disjunction found in %s" % (mysplit,)
+                ), "Normalization error, nested disjunction found in {}".format(mysplit)
             else:
                 assert (
                     x[0] == "||"
-                ), "Normalization error, nested conjunction found in %s" % (mysplit,)
+                ), "Normalization error, nested conjunction found in {}".format(mysplit)
             x_exp = _expand_new_virtuals(
                 x,
                 edebug,
@@ -107,7 +109,7 @@ def _expand_new_virtuals(
                         # must be a disjunction.
                         assert (
                             x and x[0] == "||"
-                        ), "Normalization error, nested conjunction found in %s" % (
+                        ), "Normalization error, nested conjunction found in {}".format(
                             x_exp,
                         )
                         newsplit.extend(x[1:])
@@ -253,7 +255,7 @@ def _expand_new_virtuals(
                     del mytrees["virt_parent"]
 
             if not mycheck[0]:
-                raise ParseError("%s: %s '%s'" % (pkg, mycheck[1], depstring))
+                raise ParseError("{}: {} '{}'".format(pkg, mycheck[1], depstring))
 
             # Replace the original atom "x" with "virt_atom" which refers
             # to the specific version of the virtual whose deps we're
@@ -472,7 +474,7 @@ def dep_zapdeps(
                 avail_pkg = [replacing]
             if avail_pkg:
                 avail_pkg = avail_pkg[-1]  # highest (ascending order)
-                avail_slot = Atom("%s:%s" % (atom.cp, avail_pkg.slot))
+                avail_slot = Atom("{}:{}".format(atom.cp, avail_pkg.slot))
             if not avail_pkg:
                 all_available = False
                 all_use_satisfied = False
@@ -527,7 +529,7 @@ def dep_zapdeps(
                     avail_pkg_use = avail_pkg_use[-1]
                     if avail_pkg_use != avail_pkg:
                         avail_pkg = avail_pkg_use
-                    avail_slot = Atom("%s:%s" % (atom.cp, avail_pkg.slot))
+                    avail_slot = Atom("{}:{}".format(atom.cp, avail_pkg.slot))
 
             if not replacing and downgrade_probe is not None and graph is not None:
                 highest_in_slot = mydbapi_match_pkgs(avail_slot)
@@ -602,7 +604,7 @@ def dep_zapdeps(
             # If any version of a package is already in the graph then we
             # assume that it is preferred over other possible packages choices.
             all_installed = True
-            for atom in set(Atom(atom.cp) for atom in atoms if not atom.blocker):
+            for atom in {Atom(atom.cp) for atom in atoms if not atom.blocker}:
                 # New-style virtuals have zero cost to install.
                 if not vardb.match(atom) and not atom.startswith("virtual/"):
                     all_installed = False
@@ -906,7 +908,7 @@ def dep_check(
                 eapi=eapi,
             )
         except InvalidDependString as e:
-            return [0, "%s" % (e,)]
+            return [0, "{}".format(e)]
 
     if mysplit == []:
         # dependencies were reduced to nothing
@@ -931,7 +933,7 @@ def dep_check(
             trees=trees,
         )
     except ParseError as e:
-        return [0, "%s" % (e,)]
+        return [0, "{}".format(e)]
 
     dnf = False
     if mysettings.local_config:  # if not repoman
@@ -988,7 +990,7 @@ def _overlap_dnf(dep_struct):
         if isinstance(x, list):
             assert (
                 x and x[0] == "||"
-            ), "Normalization error, nested conjunction found in %s" % (dep_struct,)
+            ), "Normalization error, nested conjunction found in {}".format(dep_struct)
             order_map[id(x)] = i
             prev_cp = None
             for atom in _iter_flatten(x):
