@@ -43,8 +43,6 @@ except ImportError as e:
 else:
     _all_errors.append(http_client_error)
 
-_all_errors = tuple(_all_errors)
-
 
 def make_metadata_dict(data):
     warnings.warn(
@@ -529,7 +527,7 @@ def file_get(
     from portage.util import varexpand
     from portage.process import spawn
 
-    myfetch = (varexpand(x, mydict=variables) for x in portage.util.shlex_split(fcmd))
+    myfetch = [varexpand(x, mydict=variables) for x in portage.util.shlex_split(fcmd)]
     fd_pipes = {
         0: portage._get_stdin().fileno(),
         1: sys.__stdout__.fileno(),
@@ -615,10 +613,10 @@ def dir_get_metadata(
 
     try:
         conn = create_conn(baseurl, conn)[0]
-    except _all_errors as e:
+    except tuple(_all_errors) as e:
         # ftplib.FTP(host) can raise errors like this:
         #   socket.error: (111, 'Connection refused')
-        sys.stderr.write("!!! %s\n" % (e,))
+        sys.stderr.write("!!! {}\n".format(e))
         return {}
 
     out = sys.stdout
@@ -893,7 +891,7 @@ class PackageIndex:
         self._read_translation_map = {}
         if translated_keys:
             self._write_translation_map.update(translated_keys)
-            self._read_translation_map.update(((y, x) for (x, y) in translated_keys))
+            self._read_translation_map.update((y, x) for (x, y) in translated_keys)
         self.header = {}
         if self._default_header_data:
             self.header.update(self._default_header_data)
