@@ -1,4 +1,4 @@
-# Copyright 2010-2021 Gentoo Authors
+# Copyright 2010-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 __all__ = ["prepare_build_dirs"]
@@ -27,7 +27,6 @@ from portage.util import (
     normalize_path,
     writemsg,
 )
-from portage.util.file_copy import copyfile
 from portage.util.install_mask import _raise_exc
 
 
@@ -103,6 +102,15 @@ def prepare_build_dirs(myroot=None, settings=None, cleanup=False):
             apply_secpass_permissions(
                 mysettings[dir_key], uid=portage_uid, gid=portage_gid
             )
+        # The setgid bit prevents a lockfile group permission race for bug #468990.
+        ipc_kwargs = {}
+        if portage.data.secpass >= 1:
+            ipc_kwargs["gid"] = portage_gid
+            ipc_kwargs["mode"] = 0o2770
+        ensure_dirs(
+            os.path.join(mysettings["PORTAGE_BUILDDIR"], ".ipc"),
+            **ipc_kwargs,
+        )
     except PermissionDenied as e:
         writemsg(_("Permission Denied: %s\n") % str(e), noiselevel=-1)
         return 1
@@ -143,7 +151,7 @@ def _adjust_perms_msg(settings, msg):
                 mode="ab",
             )
             log_file_real = log_file
-        except IOError:
+        except OSError:
 
             def write(msg):
                 pass
@@ -229,11 +237,9 @@ def _prepare_features_dirs(mysettings):
                                 except OSError:
                                     continue
                                 if subdir_st.st_gid != portage_gid or (
-                                    (
-                                        stat.S_ISDIR(subdir_st.st_mode)
-                                        and not dirmode
-                                        == (stat.S_IMODE(subdir_st.st_mode) & dirmode)
-                                    )
+                                    stat.S_ISDIR(subdir_st.st_mode)
+                                    and not dirmode
+                                    == (stat.S_IMODE(subdir_st.st_mode) & dirmode)
                                 ):
                                     droppriv_fix = True
                                     break
@@ -388,7 +394,7 @@ def _prepare_workdir(mysettings):
             log_subdir = os.path.join(logdir, "build", mysettings["CATEGORY"])
             mysettings["PORTAGE_LOG_FILE"] = os.path.join(
                 log_subdir,
-                "%s:%s.log%s" % (mysettings["PF"], logid_time, compress_log_ext),
+                "{}:{}.log{}".format(mysettings["PF"], logid_time, compress_log_ext),
             )
         else:
             log_subdir = logdir
@@ -409,13 +415,14 @@ def _prepare_workdir(mysettings):
             try:
                 _ensure_log_subdirs(logdir, log_subdir)
             except PortageException as e:
-                writemsg("!!! %s\n" % (e,), noiselevel=-1)
+                writemsg("!!! {}\n".format(e), noiselevel=-1)
 
             if os.access(log_subdir, os.W_OK):
                 logdir_subdir_ok = True
             else:
                 writemsg(
-                    "!!! %s: %s\n" % (_("Permission Denied"), log_subdir), noiselevel=-1
+                    "!!! {}: {}\n".format(_("Permission Denied"), log_subdir),
+                    noiselevel=-1,
                 )
 
     tmpdir_log_path = os.path.join(mysettings["T"], "build.log%s" % compress_log_ext)
@@ -479,20 +486,16 @@ def _ensure_log_subdirs(logdir, subdir):
 
 def _prepare_fake_filesdir(settings):
     real_filesdir = settings["O"] + "/files"
-    filesdir = settings["FILESDIR"]
+    symlink_path = settings["FILESDIR"]
 
-    # Copy files from real directory to ebuild directory (without metadata).
-    if os.path.isdir(real_filesdir):
-        shutil.copytree(real_filesdir, filesdir, copy_function=copyfile)
-        apply_recursive_permissions(
-            filesdir,
-            uid=portage_uid,
-            gid=portage_gid,
-            dirmode=0o750,
-            dirmask=0,
-            filemode=0o640,
-            filemask=0,
-        )
+    try:
+        link_target = os.readlink(symlink_path)
+    except OSError:
+        os.symlink(real_filesdir, symlink_path)
+    else:
+        if link_target != real_filesdir:
+            os.unlink(symlink_path)
+            os.symlink(real_filesdir, symlink_path)
 
 
 def _prepare_fake_distdir(settings, alist):
