@@ -184,9 +184,6 @@ class IsValidAtom(TestCase):
             IsValidAtomTestCase(
                 "sys-apps/portage::repo", False, allow_repo=None, eapi="5"
             ),
-            IsValidAtomTestCase(
-                "sys-apps/portage::repo", True, allow_repo=None, eapi="5-progress"
-            ),
             IsValidAtomTestCase(
                 "sys-apps/portage::repo", False, allow_repo=None, eapi="7"
             ),
@@ -195,9 +192,6 @@ class IsValidAtom(TestCase):
             IsValidAtomTestCase(
                 "sys-apps/portage::repo", False, allow_repo=False, eapi="5"
             ),
-            IsValidAtomTestCase(
-                "sys-apps/portage::repo", False, allow_repo=False, eapi="5-progress"
-            ),
             IsValidAtomTestCase(
                 "sys-apps/portage::repo", False, allow_repo=False, eapi="7"
             ),
@@ -205,9 +199,6 @@ class IsValidAtom(TestCase):
             IsValidAtomTestCase(
                 "sys-apps/portage::repo", True, allow_repo=True, eapi="5"
             ),
-            IsValidAtomTestCase(
-                "sys-apps/portage::repo", True, allow_repo=True, eapi="5-progress"
-            ),
             IsValidAtomTestCase(
                 "sys-apps/portage::repo", True, allow_repo=True, eapi="7"
             ),
@@ -239,5 +230,5 @@ class IsValidAtom(TestCase):
                     )
                 ),
                 test_case.expected,
-                msg="isvalidatom(%s) != %s" % (test_case.atom, test_case.expected),
+                msg="isvalidatom({}) != {}".format(test_case.atom, test_case.expected),
             )
