@@ -13,6 +13,7 @@ from portage.const import (
     GLOBAL_CONFIG_PATH,
     PORTAGE_BIN_PATH,
     USER_CONFIG_PATH,
+    SUPPORTED_GENTOO_BINPKG_FORMATS,
 )
 from portage.process import find_binary
 from portage.dep import Atom, _repo_separator
@@ -23,6 +24,8 @@ from portage._sets.base import InternalPackageSet
 from portage.tests import cnf_path
 from portage.util import ensure_dirs, normalize_path
 from portage.versions import catsplit
+from portage.exception import InvalidBinaryPackageFormat
+from portage.gpg import GPG
 
 import _emerge
 from _emerge.actions import _calc_depclean
@@ -32,11 +35,6 @@ from _emerge.DependencyArg import DependencyArg
 from _emerge.depgraph import backtrack_depgraph
 from _emerge.RootConfig import RootConfig
 
-try:
-    from repoman.tests import cnf_path_repoman
-except ImportError:
-    cnf_path_repoman = None
-
 
 class ResolverPlayground:
     """
@@ -60,14 +58,11 @@ class ResolverPlayground:
             "packages",
             "package.unmask",
             "package.use",
-            "package.use.aliases",
             "package.use.force",
             "package.use.mask",
             "package.use.stable.force",
             "package.use.stable.mask",
             "soname.provided",
-            "unpack_dependencies",
-            "use.aliases",
             "use.force",
             "use.mask",
             "layout.conf",
@@ -134,8 +129,11 @@ class ResolverPlayground:
         """
 
         self.debug = debug
-        if eprefix is None:
-            self.eprefix = normalize_path(tempfile.mkdtemp())
+        if True:
+            if eprefix is None:
+                self.eprefix = normalize_path(tempfile.mkdtemp())
+            else:
+                self.eprefix = normalize_path(eprefix)
 
             # EPREFIX/bin is used by fake true_binaries. Real binaries goes into EPREFIX/usr/bin
             eubin = os.path.join(self.eprefix, "usr", "bin")
@@ -151,6 +149,7 @@ class ResolverPlayground:
             essential_binaries = (
                 "awk",
                 "basename",
+                "bash",
                 "bzip2",
                 "cat",
                 "chgrp",
@@ -161,6 +160,7 @@ class ResolverPlayground:
                 "egrep",
                 "env",
                 "find",
+                "flock",
                 "grep",
                 "head",
                 "install",
@@ -195,8 +195,6 @@ class ResolverPlayground:
                     os.symlink(path, os.path.join(eubin, x))
             finally:
                 os.environ["PATH"] = orig_path
-        else:
-            self.eprefix = normalize_path(eprefix)
 
         # Tests may override portage.const.EPREFIX in order to
         # simulate a prefix installation. It's reasonable to do
@@ -225,7 +223,6 @@ class ResolverPlayground:
 
         self._create_distfiles(distfiles)
         self._create_ebuilds(ebuilds)
-        self._create_binpkgs(binpkgs)
         self._create_installed(installed)
         self._create_profile(
             ebuilds, eclasses, installed, profile, repo_configs, user_config, sets
@@ -234,6 +231,8 @@ class ResolverPlayground:
 
         self.settings, self.trees = self._load_config()
 
+        self.gpg = None
+        self._create_binpkgs(binpkgs)
         self._create_ebuild_manifests(ebuilds)
 
         portage.util.noiselimit = 0
@@ -313,7 +312,7 @@ class ResolverPlayground:
                     f.write(copyright_header)
                 f.write('EAPI="%s"\n' % eapi)
                 for k, v in metadata.items():
-                    f.write('%s="%s"\n' % (k, v))
+                    f.write('{}="{}"\n'.format(k, v))
                 if misc_content is not None:
                     f.write(misc_content)
 
@@ -341,6 +340,13 @@ class ResolverPlayground:
         # a dict.
         items = getattr(binpkgs, "items", None)
         items = items() if items is not None else binpkgs
+        binpkg_format = self.settings.get(
+            "BINPKG_FORMAT", SUPPORTED_GENTOO_BINPKG_FORMATS[0]
+        )
+        if binpkg_format == "gpkg":
+            if self.gpg is None:
+                self.gpg = GPG(self.settings)
+                self.gpg.unlock()
         for cpv, metadata in items:
             a = Atom("=" + cpv, allow_repo=True)
             repo = a.repo
@@ -356,19 +362,40 @@ class ResolverPlayground:
             metadata["repository"] = repo
             metadata["CATEGORY"] = cat
             metadata["PF"] = pf
+            metadata["BINPKG_FORMAT"] = binpkg_format
 
             repo_dir = self.pkgdir
             category_dir = os.path.join(repo_dir, cat)
             if "BUILD_ID" in metadata:
-                binpkg_path = os.path.join(
-                    category_dir, pn, "%s-%s.xpak" % (pf, metadata["BUILD_ID"])
-                )
+                if binpkg_format == "xpak":
+                    binpkg_path = os.path.join(
+                        category_dir, pn, "{}-{}.xpak".format(pf, metadata["BUILD_ID"])
+                    )
+                elif binpkg_format == "gpkg":
+                    binpkg_path = os.path.join(
+                        category_dir,
+                        pn,
+                        "{}-{}.gpkg.tar".format(pf, metadata["BUILD_ID"]),
+                    )
+                else:
+                    raise InvalidBinaryPackageFormat(binpkg_format)
             else:
-                binpkg_path = os.path.join(category_dir, pf + ".tbz2")
+                if binpkg_format == "xpak":
+                    binpkg_path = os.path.join(category_dir, pf + ".tbz2")
+                elif binpkg_format == "gpkg":
+                    binpkg_path = os.path.join(category_dir, pf + ".gpkg.tar")
+                else:
+                    raise InvalidBinaryPackageFormat(binpkg_format)
 
             ensure_dirs(os.path.dirname(binpkg_path))
-            t = portage.xpak.tbz2(binpkg_path)
-            t.recompose_mem(portage.xpak.xpak_mem(metadata))
+            if binpkg_format == "xpak":
+                t = portage.xpak.tbz2(binpkg_path)
+                t.recompose_mem(portage.xpak.xpak_mem(metadata))
+            elif binpkg_format == "gpkg":
+                t = portage.gpkg.gpkg(self.settings, a.cpv, binpkg_path)
+                t.compress(os.path.dirname(binpkg_path), metadata)
+            else:
+                raise InvalidBinaryPackageFormat(binpkg_format)
 
     def _create_installed(self, installed):
         for cpv in installed:
@@ -412,7 +439,7 @@ class ResolverPlayground:
             with open(ebuild_path, "w") as f:
                 f.write('EAPI="%s"\n' % metadata.pop("EAPI", "0"))
                 for k, v in metadata.items():
-                    f.write('%s="%s"\n' % (k, v))
+                    f.write('{}="{}"\n'.format(k, v))
 
             env_path = os.path.join(vdb_pkg_dir, "environment.bz2")
             with bz2.BZ2File(env_path, mode="w") as f:
@@ -492,7 +519,7 @@ class ResolverPlayground:
 
             for eclass_name, eclass_content in eclasses.items():
                 with open(
-                    os.path.join(eclass_dir, "{}.eclass".format(eclass_name)), "wt"
+                    os.path.join(eclass_dir, "{}.eclass".format(eclass_name)), "w"
                 ) as f:
                     if isinstance(eclass_content, str):
                         eclass_content = [eclass_content]
@@ -545,11 +572,18 @@ class ResolverPlayground:
                     sub_profile_dir, os.path.join(user_config_dir, "make.profile")
                 )
 
+        gpg_test_path = os.environ["PORTAGE_GNUPGHOME"]
+
         make_conf = {
             "ACCEPT_KEYWORDS": "x86",
+            "BINPKG_GPG_SIGNING_BASE_COMMAND": f"flock {gpg_test_path}/portage-binpkg-gpg.lock /usr/bin/gpg --sign --armor --yes --pinentry-mode loopback --passphrase GentooTest [PORTAGE_CONFIG]",
+            "BINPKG_GPG_SIGNING_GPG_HOME": gpg_test_path,
+            "BINPKG_GPG_SIGNING_KEY": "0x5D90EA06352177F6",
+            "BINPKG_GPG_VERIFY_GPG_HOME": gpg_test_path,
             "CLEAN_DELAY": "0",
             "DISTDIR": self.distdir,
             "EMERGE_WARNING_DELAY": "0",
+            "FEATURES": "${FEATURES} binpkg-signing gpg-keepalive",
             "PKGDIR": self.pkgdir,
             "PORTAGE_INST_GID": str(portage.data.portage_gid),
             "PORTAGE_INST_UID": str(portage.data.portage_uid),
@@ -572,6 +606,10 @@ class ResolverPlayground:
 
         if "make.conf" in user_config:
             make_conf_lines.extend(user_config["make.conf"])
+            if "BINPKG_FORMAT=gpkg" in user_config["make.conf"]:
+                make_conf_lines.append(
+                    'FEATURES="${FEATURES} binpkg-request-signature"'
+                )
 
         if not portage.process.sandbox_capable or os.environ.get("SANDBOX_ON") == "1":
             # avoid problems from nested sandbox instances
@@ -625,11 +663,6 @@ class ResolverPlayground:
                 for line in lines:
                     f.write("%s\n" % line)
 
-        if cnf_path_repoman is not None:
-            # Create /usr/share/repoman
-            repoman_share_dir = os.path.join(self.eroot, "usr", "share", "repoman")
-            os.symlink(cnf_path_repoman, repoman_share_dir)
-
     def _create_world(self, world, world_sets):
         # Create /var/lib/portage/world
         var_lib_portage = os.path.join(self.eroot, "var", "lib", "portage")
@@ -657,7 +690,7 @@ class ResolverPlayground:
                 "[%s]\n%s"
                 % (
                     repo_name,
-                    "\n".join("%s = %s" % (k, v) for k, v in repo_config.items()),
+                    "\n".join("{} = {}".format(k, v) for k, v in repo_config.items()),
                 )
                 for repo_name, repo_config in self._repositories.items()
             )
@@ -742,6 +775,8 @@ class ResolverPlayground:
                 return
 
     def cleanup(self):
+        if self.gpg is not None:
+            self.gpg.stop()
         for eroot in self.trees:
             portdb = self.trees[eroot]["porttree"].dbapi
             portdb.close_caches()
@@ -909,7 +944,7 @@ class ResolverPlaygroundTestCase:
                 expected = set(expected)
 
             elif key == "forced_rebuilds" and expected is not None:
-                expected = dict((k, set(v)) for k, v in expected.items())
+                expected = {k: set(v) for k, v in expected.items()}
 
             if got != expected:
                 fail_msgs.append(
@@ -947,7 +982,7 @@ def _mergelist_str(x, depgraph):
                 desc = x.type_name
             else:
                 desc = x.operation
-            mergelist_str = "[%s]%s" % (desc, mergelist_str)
+            mergelist_str = "[{}]{}".format(desc, mergelist_str)
         if x.root != depgraph._frozen_config._running_root.root:
             mergelist_str += "{targetroot}"
     return mergelist_str
@@ -1047,17 +1082,17 @@ class ResolverPlaygroundResult:
             )
 
         if self.depgraph._dynamic_config._unsatisfied_deps_for_display:
-            self.unsatisfied_deps = set(
+            self.unsatisfied_deps = {
                 dep_info[0][1]
                 for dep_info in self.depgraph._dynamic_config._unsatisfied_deps_for_display
-            )
+            }
 
         if self.depgraph._forced_rebuilds:
-            self.forced_rebuilds = dict(
-                (child.cpv, set(parent.cpv for parent in parents))
+            self.forced_rebuilds = {
+                child.cpv: {parent.cpv for parent in parents}
                 for child_dict in self.depgraph._forced_rebuilds.values()
                 for child, parents in child_dict.items()
-            )
+            }
 
         required_use_unsatisfied = []
         for (
