@@ -1,16 +1,20 @@
 # Copyright 2012-2019 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
+import sys
+
+from portage.const import SUPPORTED_GENTOO_BINPKG_FORMATS
 from portage.tests import TestCase
 from portage.tests.resolver.ResolverPlayground import (
     ResolverPlayground,
     ResolverPlaygroundTestCase,
 )
+from portage.output import colorize
 
 
 class SlotAbiTestCase(TestCase):
     def __init__(self, *args, **kwargs):
-        super(SlotAbiTestCase, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def testSubSlot(self):
         ebuilds = {
@@ -118,19 +122,29 @@ class SlotAbiTestCase(TestCase):
             ),
         )
 
-        playground = ResolverPlayground(
-            ebuilds=ebuilds,
-            binpkgs=binpkgs,
-            installed=installed,
-            world=world,
-            debug=False,
-        )
-        try:
-            for test_case in test_cases:
-                playground.run_TestCase(test_case)
-                self.assertEqual(test_case.test_success, True, test_case.fail_msg)
-        finally:
-            playground.cleanup()
+        for binpkg_format in SUPPORTED_GENTOO_BINPKG_FORMATS:
+            with self.subTest(binpkg_format=binpkg_format):
+                print(colorize("HILITE", binpkg_format), end=" ... ")
+                sys.stdout.flush()
+                playground = ResolverPlayground(
+                    ebuilds=ebuilds,
+                    binpkgs=binpkgs,
+                    installed=installed,
+                    world=world,
+                    debug=False,
+                    user_config={
+                        "make.conf": ('BINPKG_FORMAT="%s"' % binpkg_format,),
+                    },
+                )
+
+                try:
+                    for test_case in test_cases:
+                        playground.run_TestCase(test_case)
+                        self.assertEqual(
+                            test_case.test_success, True, test_case.fail_msg
+                        )
+                finally:
+                    playground.cleanup()
 
     def testWholeSlot(self):
         ebuilds = {
@@ -243,19 +257,29 @@ class SlotAbiTestCase(TestCase):
             ),
         )
 
-        playground = ResolverPlayground(
-            ebuilds=ebuilds,
-            binpkgs=binpkgs,
-            installed=installed,
-            world=world,
-            debug=False,
-        )
-        try:
-            for test_case in test_cases:
-                playground.run_TestCase(test_case)
-                self.assertEqual(test_case.test_success, True, test_case.fail_msg)
-        finally:
-            playground.cleanup()
+        for binpkg_format in SUPPORTED_GENTOO_BINPKG_FORMATS:
+            with self.subTest(binpkg_format=binpkg_format):
+                print(colorize("HILITE", binpkg_format), end=" ... ")
+                sys.stdout.flush()
+                playground = ResolverPlayground(
+                    ebuilds=ebuilds,
+                    binpkgs=binpkgs,
+                    installed=installed,
+                    world=world,
+                    debug=False,
+                    user_config={
+                        "make.conf": ('BINPKG_FORMAT="%s"' % binpkg_format,),
+                    },
+                )
+
+                try:
+                    for test_case in test_cases:
+                        playground.run_TestCase(test_case)
+                        self.assertEqual(
+                            test_case.test_success, True, test_case.fail_msg
+                        )
+                finally:
+                    playground.cleanup()
 
     def testWholeSlotConditional(self):
         ebuilds = {
@@ -447,16 +471,26 @@ class SlotAbiTestCase(TestCase):
             ),
         )
 
-        playground = ResolverPlayground(
-            ebuilds=ebuilds,
-            binpkgs=binpkgs,
-            installed=installed,
-            world=world,
-            debug=False,
-        )
-        try:
-            for test_case in test_cases:
-                playground.run_TestCase(test_case)
-                self.assertEqual(test_case.test_success, True, test_case.fail_msg)
-        finally:
-            playground.cleanup()
+        for binpkg_format in SUPPORTED_GENTOO_BINPKG_FORMATS:
+            with self.subTest(binpkg_format=binpkg_format):
+                print(colorize("HILITE", binpkg_format), end=" ... ")
+                sys.stdout.flush()
+                playground = ResolverPlayground(
+                    ebuilds=ebuilds,
+                    binpkgs=binpkgs,
+                    installed=installed,
+                    world=world,
+                    debug=False,
+                    user_config={
+                        "make.conf": ('BINPKG_FORMAT="%s"' % binpkg_format,),
+                    },
+                )
+
+                try:
+                    for test_case in test_cases:
+                        playground.run_TestCase(test_case)
+                        self.assertEqual(
+                            test_case.test_success, True, test_case.fail_msg
+                        )
+                finally:
+                    playground.cleanup()
